==> openshift-client-4.13.2-sources.jar: io/fabric8/openshift/client/dsl/internal/AppliedClusterResourceQuotaOperationsImpl.java <==

                
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.DoneableAppliedClusterResourceQuota;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuota;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuotaList;
import io.fabric8.openshift.api.model.DoneableAppliedClusterResourceQuota;

import java.util.Map;
import java.util.TreeMap;


public class AppliedClusterResourceQuotaOperationsImpl extends OpenShiftOperation<AppliedClusterResourceQuota, AppliedClusterResourceQuotaList, DoneableAppliedClusterResourceQuota, Resource<AppliedClusterResourceQuota, DoneableAppliedClusterResourceQuota>> {

  public AppliedClusterResourceQuotaOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public AppliedClusterResourceQuotaOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("quota.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("appliedclusterresourcequotas"));
    this.type = AppliedClusterResourceQuota.class;
    this.listType = AppliedClusterResourceQuotaList.class;
    this.doneableType = DoneableAppliedClusterResourceQuota.class;
  }

  public AppliedClusterResourceQuotaOperationsImpl newInstance(OperationContext context) {
    return new AppliedClusterResourceQuotaOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}

==> openshift-client-5.1.1-sources.jar: io/fabric8/openshift/client/dsl/internal/AppliedClusterResourceQuotaOperationsImpl.java <==

                            
      

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.AppliedClusterResourceQuota;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuotaBuilder;
import io.fabric8.openshift.api.model.AppliedClusterResourceQuotaList;

import java.util.Map;
import java.util.TreeMap;


public class AppliedClusterResourceQuotaOperationsImpl extends OpenShiftOperation<AppliedClusterResourceQuota, AppliedClusterResourceQuotaList, Resource<AppliedClusterResourceQuota>> {

  public AppliedClusterResourceQuotaOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public AppliedClusterResourceQuotaOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("quota.openshift.io")
    .withApiGroupVersion("v1")
    .withPlural("appliedclusterresourcequotas"));
    this.type = AppliedClusterResourceQuota.class;
    this.listType = AppliedClusterResourceQuotaList.class;
  }

  public AppliedClusterResourceQuotaOperationsImpl newInstance(OperationContext context) {
    return new AppliedClusterResourceQuotaOperationsImpl(context);
  }

  @Override
  public AppliedClusterResourceQuota edit(Visitor... visitors) {
    return patch(new AppliedClusterResourceQuotaBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return true;
  }
}
